@@ -12,7 +12,8 @@
 #' @param data (`data.frame`)\cr
 #'   a data frame
 #' @param .by ([`tidy-select`][dplyr::dplyr_tidy_select])\cr
-#'   columns to tabulate by in the series of ARD function calls
+#'   columns to tabulate by in the series of ARD function calls.
+#'   Any rows with `NA` or `NaN` values are removed from all calculations.
 #' @param ... ([`dynamic-dots`][rlang::dyn-dots])\cr
 #'   Series of ARD function calls to be run and stacked
 #' @param .overall (`logical`)\cr logical indicating whether overall statistics
@@ -24,20 +25,22 @@
 #' @param .attributes (`logical`)\cr
 #'   logical indicating whether to include the results of `ard_attributes()` for all
 #'   variables represented in the ARD. Default is `FALSE`.
-#' @param .shuffle (`logical`)\cr
-#'   logical indicating whether to perform `shuffle_ard()` on the final result.
-#'   Default is `FALSE`.
+#' @param .shuffle `r lifecycle::badge("deprecated")` support for `.shuffle = TRUE`
+#'   will be removed in the next release. `ard_stack()` will no longer shuffle.
+#'   `shuffle_ard()` should be called separately.
 #' @param .total_n (`logical`)\cr
 #'   logical indicating whether to include of `ard_total_n()` in the returned ARD.
+#' @param .by_stats (`logical`)\cr
+#'   logical indicating whether to include overall stats of the `by` variables in the returned ARD.
 #'
-#' @return  a transformed ARD data frame (of class 'card' if `.shuffle = FALSE`)
+#' @return an ARD data frame of class 'card'
 #' @export
 #'
 #' @examples
 #' ard_stack(
 #'   data = ADSL,
-#'   ard_categorical(variables = "AGEGR1"),
-#'   ard_continuous(variables = "AGE"),
+#'   ard_tabulate(variables = "AGEGR1"),
+#'   ard_summary(variables = "AGE"),
 #'   .by = "ARM",
 #'   .overall = TRUE,
 #'   .attributes = TRUE
@@ -45,8 +48,8 @@
 #'
 #' ard_stack(
 #'   data = ADSL,
-#'   ard_categorical(variables = "AGEGR1"),
-#'   ard_continuous(variables = "AGE"),
+#'   ard_tabulate(variables = "AGEGR1"),
+#'   ard_summary(variables = "AGE"),
 #'   .by = "ARM",
 #'   .shuffle = TRUE
 #' )
@@ -58,7 +61,8 @@ ard_stack <- function(data,
                       .missing = FALSE,
                       .attributes = FALSE,
                       .total_n = FALSE,
-                      .shuffle = FALSE) {
+                      .shuffle = FALSE,
+                      .by_stats = TRUE) {
   set_cli_abort_call()
 
   # process arguments ----------------------------------------------------------
@@ -73,6 +77,7 @@ ard_stack <- function(data,
   check_scalar_logical(.attributes)
   check_scalar_logical(.shuffle)
   check_scalar_logical(.total_n)
+  check_scalar_logical(.by_stats)
 
   if (is_empty(.by) && isTRUE(.overall)) {
     cli::cli_inform(
@@ -83,10 +88,19 @@ ard_stack <- function(data,
     .overall <- FALSE
   }
 
-  # evaluate the dots using common `data` and `by`
+  # remove missing `.by` rows --------------------------------------------------
+  df_na_by <- is.na(data[.by]) | apply(data[.by], MARGIN = 2, is.nan)
+  if (!is_empty(.by) && any(df_na_by)) {
+    rows_with_na <- apply(df_na_by, MARGIN = 1, any)
+    cli::cli_inform(c("*" = "Removing {.val {sum(rows_with_na)}} row{?s} with
+                            {.val {NA}} or {.val {NaN}} values in {.val {eval(.by)}} column{?s}."))
+    data <- data[!rows_with_na, ]
+  }
+
+  # evaluate the dots using common `data` and `by` -----------------------------
   ard_list <- .eval_ard_calls(data, .by, ...)
 
-  # add overall
+  # add overall ----------------------------------------------------------------
   if (isTRUE(.overall)) {
     ard_list <- c(
       ard_list,
@@ -94,11 +108,11 @@ ard_stack <- function(data,
     )
   }
 
-  # compute Ns by group / combine main calls
-  if (!is_empty(by)) {
+  # compute Ns by group / combine main calls -----------------------------------
+  if (!is_empty(by) && isTRUE(.by_stats)) {
     ard_full <- bind_ard(
       ard_list,
-      ard_categorical(
+      ard_tabulate(
         data = data,
         variables = all_of(.by)
       )
@@ -107,10 +121,10 @@ ard_stack <- function(data,
     ard_full <- bind_ard(ard_list, .update = TRUE)
   }
 
-  # get all variables represented
+  # get all variables represented ----------------------------------------------
   variables <- unique(ard_full$variable) |> setdiff(.by)
 
-  # missingness
+  # missingness ----------------------------------------------------------------
   if (isTRUE(.missing)) {
     ard_full <- bind_ard(
       ard_full,
@@ -124,7 +138,7 @@ ard_stack <- function(data,
     }
   }
 
-  # attributes
+  # attributes -----------------------------------------------------------------
   if (isTRUE(.attributes)) {
     ard_full <- bind_ard(
       ard_full,
@@ -132,7 +146,7 @@ ard_stack <- function(data,
     )
   }
 
-  # total n
+  # total n --------------------------------------------------------------------
   if (isTRUE(.total_n)) {
     ard_full <- bind_ard(
       ard_full,
@@ -140,14 +154,25 @@ ard_stack <- function(data,
     )
   }
 
-  # order
+  # order ----------------------------------------------------------------------
   ard_full <- tidy_ard_row_order(ard_full)
 
-  # shuffle
+  # append attributes ----------------------------------------------------------
+  attr(ard_full, "args") <- list(
+    by = .by
+  )
+
+  # shuffle --------------------------------------------------------------------
   if (isTRUE(.shuffle)) {
+    lifecycle::deprecate_warn(
+      when = "0.7.0",
+      what = "cards::ard_stack(.shuffle)",
+      details = "Call `shuffle_ard()` after `ard_stack()`."
+    )
     return(shuffle_ard(ard_full))
   }
 
+  # return final ARD -----------------------------------------------------------
   ard_full
 }
 
@@ -169,8 +194,8 @@ ard_stack <- function(data,
 #' cards:::.eval_ard_calls(
 #'   data = ADSL,
 #'   .by = "ARM",
-#'   ard_categorical(variables = "AGEGR1"),
-#'   ard_continuous(variables = "AGE")
+#'   ard_tabulate(variables = "AGEGR1"),
+#'   ard_summary(variables = "AGE")
 #' )
 .eval_ard_calls <- function(data, .by, ...) {
   # capture quosures -----------------------------------------------------------
