@@ -17,7 +17,7 @@ test_that("tidy_ard_column_order() works", {
       x10 = sample(LETTERS[19:20], 30, replace = TRUE),
       dummy = 1L
     ) |>
-      ard_categorical(
+      ard_tabulate(
         variables = "dummy",
         strata = x1:x10,
         statistic = everything() ~ "n"
@@ -25,10 +25,17 @@ test_that("tidy_ard_column_order() works", {
       dplyr::select(all_ard_groups(), all_ard_variables()) |>
       names(),
     c(
-      "group1", "group1_level", "group2", "group2_level", "group3", "group3_level",
-      "group4", "group4_level", "group5", "group5_level", "group6", "group6_level",
-      "group7", "group7_level", "group8", "group8_level", "group9", "group9_level",
-      "group10", "group10_level", "variable", "variable_level"
+      "group1", "group1_level",
+      "group2", "group2_level",
+      "group3", "group3_level",
+      "group4", "group4_level",
+      "group5", "group5_level",
+      "group6", "group6_level",
+      "group7", "group7_level",
+      "group8", "group8_level",
+      "group9", "group9_level",
+      "group10", "group10_level",
+      "variable", "variable_level"
     )
   )
 })
